; 15N-T1rho relaxation experiment with sensitivity enhanced (Rance-Kay) HSQC read-out
; for 15N, 2H15N, 15N13C and 2H15N13C labelled proteins
; builts on a sequence by Lakomek et al., JBNMR 2012
; new version by Tobias Stief October 2022
;last update Dec 2023

#include <Avance.incl>
#include <Grad.incl>
#include <Delay.incl>


;#define LABEL_CN  ; switch on for 13C labelled samples
define list<pulse> vplist = <$VPLIST>
#define TEMP_COMPENSATION


"acqt0=0"

"in0=inf1*0.5"


"d0=10u"
"d11=30m"
"d26=p7-p1"
"DELTA=2.65m"
"DELTA1=2.65m-200u-p21"
"DELTA2=2.65m-200u-p22"
"DELTA3=2.65m-200u-p23"
"DELTA4=p25-p19*0.63"
"DELTA5=2.65m-p26-200u"
"DELTA8=2.65m-200u-p24"
"l1=1"
"l2=1"

#  ifdef LABEL_CN 
"DELTA6=d0*2+26u+p4*4"	;+10u if gp10 active
# else
"DELTA6=d0*2+p1*2"	;+10u if gp10 active
# endif

"cnst21=176"
"cnst22=56"
"cnst18=-800"

"spoff4=bf2*((cnst22-cnst21)/1000000)"



1	ze
	1m 
2	2m do:f3
	1m do:f2
	1m
	d11 
3	3m 
4	1m 
5	1m do:f3
	1m do:f2
	1m BLKGRAD
	10u pl1:f1
	10u pl4:f2



;---------temperature compensation------------ 
# ifdef TEMP_COMPENSATION
"p17=p18+1m-vplist"
"d17=d1-p17"
# endif
	


;-------delays for spin lock relaxation period-------
"d8=p8+vplist*0.25-p15*0.5+1u"
"d9=vplist*0.5-p15+2u"
"d29=p8+vplist*0.5+2u-p4*2-8u"



	 
;-------- Temperature compensation and d1 recovery delay----------------        
#ifdef TEMP_COMPENSATION
	10u fq=cnst18(bf ppm):f3
  10u pl8:f3
  (p17 ph0):f3    ; 15N pulse is applied far off-resonance      
  10u
  10u fq=0:f3
  d17
#else
  d1
#endif
	

	10u fq=cnst21(bf ppm):f2
	1m UNBLKGRAD
	10u pl7:f3

;------- kill steady state 15N ------------
	(p7 ph0):f3
	5u
	p27:gp7
	200u

;------- first INEPT Hz-> 2HxNz -------------------------
	(p1 ph0):f1
	5u
	p21:gp1
	200u
	DELTA1
	(center(p1*2 ph0):f1 (p7*2 ph0):f3)
	DELTA1
	5u
	p21:gp1
	200u
 
;------- rephase  2HxNz to Nz-----------------------------
	(p1 ph5):f1  (p7 ph0):f3 
	5u 
	p22:gp2 
	200u
	DELTA2
	(center (p1*2 ph0):f1 (p7*2 ph0):f3)
	DELTA2
	5u
	p22:gp2
	200u

	(p7 ph6):f3 ; phase-cycle Nz, -Nz for Freeman-Hill decay
	5u
;--------------------------------------------------------
	(p1 ph2):f1 ; purge pulse to kill any residual HzNz
	5u
	p28:gp8  
	100u
	50u pl8:f3  ; change to pl0:120dB for Avance I or DRX systems
	50u pl0:f1

;------ N15 T1rho relaxation period with shaped 180 H pulses for CCR compensation -----------
# ifdef LABEL_CN
	(d8 p15:sp5 ph0 d9 p15:sp5 ph0 d8):f1 (p8:sp8 ph0 4u pl8 vplist ph0 p8:sp9 ph0):f3 (d29 p4*2 ph0 3u 10u fq=cnst22(bf ppm) 3u p4*2 ph0 10u fq=cnst21(bf ppm)):f2 

#else
	(d8 p15:sp5 ph0 d9 p15:sp5 ph0 d8):f1 (p8:sp8 ph0 4u pl8 vplist ph0 p8:sp9 ph0):f3 
#endif

;------------Cleaning Gradient------------------------
	5u
	p29:gp9
	100u
	100u ;fq=0:f1
;---------- Echo- Antiecho encoding------------------------

77	3u pl7:f3
	3u pl4:f2
	3u pl1:f1
	(p7 ph7):f3


	DELTA6 ;compensation for d0 15N evolution
	DELTA5  
	190u
	p26:gp6*EA
	10u 
	(center (p1*2 ph0):f1 (p7*2 ph7):f3)
	5u 
	p26:gp6*EA*-1
	195u 
	DELTA5 
					

; t1 evolution ---------------------------------------------

	d0*0.5 ;gron10  5u groff
	d0*0.5 ;gron10*-1 5u groff

#ifdef LABEL_CN
	(center (p1*2 ph0):f1 (p4*2 ph0 3u 10u fq=cnst22(bf ppm) 3u p4*2 ph0 10u fq=cnst21(bf ppm)):f2 )
				
#else
	(p1*2 ph0):f1 
#endif
	d0
;goto 999
;--------first INEPT for sensitivity-enhanced back transfer----------------------------
	
	(center (p1 ph0):f1 (p7 ph8):f3)  
	5u
	p23:gp3
	200u
	DELTA3
	(center(p1*2 ph0):f1 (p7*2 ph0):f3)
	DELTA3
	5u
	p23:gp3
	200u

; ---second INEPT -----------------------------------------
	(center (p1 ph1):f1 (p7 ph1):f3)    
	5u
	p24:gp4
	200u
	DELTA8
	(center(p1*2 ph0):f1 (p7*2 ph0):f3)
	DELTA8
	5u
	p24:gp4
	200u
	(d26*0.5 p19 ph0:r):f1
; ------------------------spin-echo with decoding gradient EA  
998	245u
	DELTA4	
	(p1*2 ph0):f1
	5u
	p25:gp5
	200u
999	5u 
	5u pl30:f2 
	10u pl31:f3
	20u BLKGRAD
	go=2 ph31  cpds3:f3 ;cpd2:f2
	200u
	400u do:f3  
	400u do:f2
	d11 wr #0 if #0 zd
	1m 
	2m vplist.inc
	lo to 3 times l6
	1m ip8*2
	1m igrad EA
	1m ru2
	lo to 4 times 2 
	1m id0
	lo to 5 times l3
1m do:f3
1m BLKGRAD
exit    

ph0=0
ph1=1
ph2=2
ph5=1 
ph6=1 1 3 3
ph7= 1 3 
ph8= 0  
ph31=1 3 3 1


;-------------NOTES----------------------

;o1p = 4.7 ppm
;o2p=176 ppm (CO)
;o3p=119 ppm
 
;NS=4*n
;in0=inf/2
;SW=1/(2*in0)
;echo-antiecho in N15 (process as Complex in NmrDraw before splitting the spectra)


; 1H pulses
;p1:  90 deg hard 1H pulse @pl1
;p19 last 90 deg hard 1H pulse @pl1, can be adjusted for improving water-supression
;pl1: 1H 90 deg
;pl0: 1000 dB
;p15: 1000u (@ 1200 MHz) 180 deg IBurp2 pulse on 1H (sp15)
;sp5: 180 deg IBurp2 pulse on 1H (sp15) 
;spnam5: IBurp2
;spoffs5: 4680Hz @ 1200 MHz (8.6 ppm) , should be centered in amide region but not touch the water 


; 13C pulses
;p4: 13CO selective 180 deg (11.850*2us @ 1200 MHz) @pl4
;pl4: 13C 90 deg 
;sp4: 13CA selective 180 deg (11.850*2us @ 1200 MHz)  


;15N pulses
;p7 : 90 deg hard 15N pulse @pl7
;pl7: 15N 90 deg
;pl8: 15N spin-lock power
;pl0 1000 dB
;sp8 @pl8 spin-lock power
;sp9 @pl8 spin-lock power 
;spnam8 AHP TanhTan (1st half)  
;spnam9 AHP TanhTan (2nd half)
;spoal8 1
;spoal9 0
;CPDPRG3: garp (15N decoupling)
;pcpd3: 15N decoupling (200u @pl31)
;pl31: 15N decoupling power



; gradients
;p21: 200u
;p22: 200u
;p23: 800u
;p24: 200u
;p25: 201u Echo/Anti-echo decoding gradient
;p26: 1000u Echo/Anti-echo half-encoding gradient
;p27: 200u
;p28: 200u
;p29: 200u

;for z-only gradients
;gpz1: 1%
;gpz2: 2%
;gpz3: 31%
;gpz4: 11%
;gpz5: 50%
;gpz6: 50%
;gpz7: 50%
;gpz8: 5%
;gpz9: 10 % optional
;gpz10: 0.5% optional prevent t1 radiation damping 


;gpnam1 SINE.20
;gpnam2 SINE.20
;gpnam3 SINE.20
;gpnam4 SINE.20
;gpnam5 SINE.20
;gpnam6 SINE.20
;gpnam7 SINE.50
;gpnam8 SINE.20
;gpnam9 SINE.20

